%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: GE_merger.m                                                       %
% Date: 03/12/2021                                                        %
% Purpose: Solves the GE system for Y, YF and LF.                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Y,YF,LF,PHIFVEC,LAMBDAFVEC,welfare_moments] = GE_merger(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZFS,ZHL,ZFL,merger_indS,merger_indL,w,wF,L,Y0,YF0,small,vMU,BER,merger)
% Matrix code to compute GE with w/w* fixed. Takes parameters, random draws, 
% and initial guess as inputs. Outputs GE values of Y, YF, LF.

diff=1;
tol=1e-3;
iter=0;

while diff>tol && iter<51
    % Solve PE
    [K,KF,LAMBDA,LAMBDAF,MUHH,MUHF,MUFF,MUFH,PHIFVEC,LAMBDAFVEC,welfare_moments]=PE_merger(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZFS,ZHL,ZFL,merger_indS,merger_indL,w,wF,Y0,YF0,small,vMU,BER,merger);
    
    % Set up linear system composed of (A10) and (A14)
    MAT=[(1-LAMBDA)*(MUHH-1)/MUHH-1 LAMBDAF*(MUHF-1)/MUHF;LAMBDA -LAMBDAF];
    VEC=[-w*L+LAMBDAF*wF*F*KF+(1-LAMBDA)*w*F*K;LAMBDA*w*F*K-LAMBDAF*wF*F*KF];
    SOL=MAT\VEC;

    Y=SOL(1);
    YF=SOL(2);

    diff=abs(Y-Y0)+abs(YF-YF0);
    iter=iter+1;
    if iter<=5
        step=1;
    else
        step=0.5;
    end

    Y0=Y0+step*(Y-Y0);
    YF0=YF0+step*(YF-YF0);
end

% Use (A13) to solve for L* 
LF=1/wF*(wF*F*KF+YF*(1-LAMBDAF)/MUFF+Y*LAMBDA/MUFH);

end