%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: GE_wF_merger.m                                                    %
% Date: 03/12/2021                                                        %
% Purpose: Solves the GE system for Y, YF and wF.                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Y,YF,wF,PHIFVEC,LAMBDAFVEC,welfare_moments] = GE_wF_merger(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZFS,ZHL,ZFL,merger_indS,merger_indL,w,wF0,L,LF,Y0,YF0,small,vMU,BER,merger)
% Matrix code to compute GE with L and L* fixed. Takes parameters, random draws, 
% and initial guess as inputs. Outputs GE values of Y, YF, wF.

diff=1;
tol=1e-3;
iter=0;

while diff>tol && iter<51
    % Solve PE
    [K,KF,LAMBDA,LAMBDAF,MUHH,MUHF,MUFF,MUFH,PHIFVEC,LAMBDAFVEC,welfare_moments]=PE_merger(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZFS,ZHL,ZFL,merger_indS,merger_indL,w,wF0,Y0,YF0,small,vMU,BER,merger);
    
    % Set up linear system composed of (A10) and (A14)
    MAT=[(1-LAMBDA)*(MUHH-1)/MUHH-1 LAMBDAF*(MUHF-1)/MUHF -LAMBDAF*F*KF;
        LAMBDA -LAMBDAF LAMBDAF*F*KF;
        LAMBDA/MUFH (1-LAMBDAF)/MUFF F*KF-LF];                                
    VEC =[-w*L+(1-LAMBDA)*w*F*K; LAMBDA*w*F*K;0];               
    SOL=MAT\VEC;

    Y=SOL(1);
    YF=SOL(2);
    wF=SOL(3);

    diff=abs(Y-Y0)+abs(YF-YF0)+abs(100*(wF-wF0));
    iter=iter+1;
    if iter<=15
        step=0.5;
    else
        step=0.2;
    end

    Y0=Y0+step*(Y-Y0);
    YF0=YF0+step*(YF-YF0);
    wF0=wF0+step/2*(wF-wF0);
end

end