%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: PE_merger.m                                                       %
% Date: 03/12/2021                                                        %
% Purpose: Solves the PE loop - splitting into small and large            %
% firms and solving each category separately.                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [K,KF,LAMBDA,LAMBDAF,MUHH,MUHF,MUFF,MUFH,PHIFVEC,LAMBDAFVEC,welfare_moments] = PE_merger(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZFS,ZHL,ZFL,merger_indS,merger_indL,w,wF,Y0,YF0,small,vMU,BER,merger)
% Takes parameters, random draws, and initial guess as inputs. Outputs are
% K, Lambda, and aggregate markup MU in both countries. 

S=size(ZHL,2)+size(ZHS,2); % fix number of sectors

ALPHAS=ALPHA(small);
ALPHAL=ALPHA(~small);

% Initialize vectors that contain PE data
MUHHVEC=zeros(1,S);
MUHFVEC=zeros(1,S);
MUFFVEC=zeros(1,S);
MUFHVEC=zeros(1,S);
KVEC=zeros(1,S);
KFVEC=zeros(1,S);
LAMBDAHVEC=zeros(1,S);
LAMBDAFVEC=zeros(1,S); 
PHIFVEC=zeros(1,S);
welfare_moments=zeros(4,S);


% Solve inner loops separately for small and large sectors (for speed)
[KVEC(small),KFVEC(small),MUHHVEC(small),MUHFVEC(small),MUFFVEC(small),MUFHVEC(small),LAMBDAHVEC(small),LAMBDAFVEC(small),PHIFVEC(small),welfare_moments(:,small)]=...
    Inner_Loops(sigma,theta,F,tau,ALPHAS',RTS,ZHS,ZFS,merger_indS,w,wF,Y0,YF0,vMU,BER,S,merger);
[KVEC(~small),KFVEC(~small),MUHHVEC(~small),MUHFVEC(~small),MUFFVEC(~small),MUFHVEC(~small),LAMBDAHVEC(~small),LAMBDAFVEC(~small),PHIFVEC(~small),welfare_moments(:,~small)]=...
    Inner_Loops(sigma,theta,F,tau,ALPHAL',RTL,ZHL,ZFL,merger_indL,w,wF,Y0,YF0,vMU,BER,S,merger);

%Take averages of vectors to obtain aggregates
K=sum(KVEC);                                                               
KF=sum(KFVEC);                                                             
LAMBDA=sum(ALPHA'.*LAMBDAHVEC);
LAMBDAF=sum(ALPHA'.*LAMBDAFVEC);
MUHH=(1-LAMBDA)/sum(ALPHA'.*MUHHVEC);
MUHF=LAMBDAF/sum(ALPHA'.*MUHFVEC);
MUFF=(1-LAMBDAF)/sum(ALPHA'.*MUFFVEC);
MUFH=LAMBDA/sum(ALPHA'.*MUFHVEC);
end

