%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: Create_Figs1_5.m                                                  %
% Date: 03/12/2021                                                        %
% Purpose: Plots Fig1(a), Fig1(b), Fig5(a) and Fig5(b).                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Housekeeping
clear;
close all;
clc

addpath('Results/Plot_Data');
set(0,'DefaultLegendAutoUpdate','off')

%% Load and store data
load('Figure1_Data_Gamma') % Results with sorting by Gamma^*
bar_object_home_Gamma = bar_object_home;
bar_object_foreign_Gamma = bar_object_foreign;
plot_object_Gamma = plot_object;

load('Figure1_Data_Lambda') % Results with sorting by Lambda^*
bar_object_home_Lambda = bar_object_home;
bar_object_foreign_Lambda = bar_object_foreign;
plot_object_Lambda = plot_object;

%% Define variables

IP = 10; % Number of bins
i = 2;   % Choose level of spillovers (2 corresponds to benchmark)

%% Plot graphs

% Figure 1(a)
figure(1)
hold on
bar_object = [bar_object_home_Lambda(:,i),bar_object_foreign_Lambda(:,i)];
bar(bar_object)
xlabel('Deciles of sectors by granular $\Lambda_z^\ast$','interpreter','latex','fontsize',20)
set(gca,'FontSize',16)
set(gca,'xtick',1:10)
lgd = legend('Home Welfare','Foreign Welfare');
set(lgd,'box','off','location','northwest','interpreter','latex','fontsize',20)
xlim([0.5,10.5])
ylim([-0.4 0.5])
plot([0 1],[0 0],'k:')
ax = gca;
ax.YAxis.TickLabelFormat = '%g%%';
labels = string(ax.YAxis.TickLabels); 
labels(1:2:end) = nan; 
ax.YAxis.TickLabels = labels;
saveas(gcf,'Results/Graphs/Fig1a','epsc')

% Figure 1(b)
figure(2)
hold on
bar_object = [bar_object_home_Gamma(:,i),bar_object_foreign_Gamma(:,i)];
bar(bar_object)
xlabel('Deciles of sectors by granular $\Gamma_z^\ast$','interpreter','latex','fontsize',20)
set(gca,'FontSize',16)
set(gca,'xtick',1:10)
lgd = legend('Home Welfare','Foreign Welfare');
set(lgd,'box','off','location','northwest','interpreter','latex','fontsize',20)
xlim([0.5,10.5])
ylim([-0.4 0.5])
plot([0 1],[0 0],'k:')
ax = gca;
ax.YAxis.TickLabelFormat = '%g%%';
labels = string(ax.YAxis.TickLabels);
labels(1:2:end) = nan; 
ax.YAxis.TickLabels = labels;
saveas(gcf,'Results/Graphs/Fig1b','epsc')

% Figure 5(a)
figure(3)
hold on
plot(1:IP,squeeze(plot_object_Lambda(1,i,:)),'o-','Color','[0, 0.4470, 0.7410]','linewidth',2,'MarkerSize',10)
plot(1:IP,squeeze(plot_object_Lambda(2,i,:)),'x--','Color','[0.25, 0.25, 0.25]','linewidth',2,'MarkerSize',10)
plot(1:IP,squeeze(plot_object_Lambda(3,i,:)),'s-','Color','[0.8500    0.3250    0.0980]','linewidth',2,'MarkerSize',10)
plot(1:IP,squeeze(plot_object_Lambda(4,i,:)),'v-','Color','[0.4660    0.6740    0.1880]','linewidth',2,'MarkerSize',10)
plot(0:IP+1,zeros(IP+2,1),'-','Color','[0.25,0.25,0.25]','linewidth',0.5)
xlabel('Deciles of sectors by granular $\Lambda_z^\ast$','interpreter','latex','fontsize',20)
set(gca,'FontSize',16)
set(gca,'xtick',1:10)
set(gca,'ytick',-2:2)
lgd = legend('Home Welfare','Foreign Welfare','Producer Surplus','Consumer Surplus');
set(lgd,'box','off','location','northwest','interpreter','latex','fontsize',20)
xlim([0.5, 10.5])
ylim([-2.0, 2.0])
ax = gca;
ax.YAxis.TickLabelFormat = '%g%%';
saveas(gcf,'Results/Graphs/Fig5a','epsc')

% Figure 5(b)
figure(4)
hold on
plot(1:IP,squeeze(plot_object_Gamma(1,i,:)),'o-','Color','[0, 0.4470, 0.7410]','linewidth',2,'MarkerSize',10)
plot(1:IP,squeeze(plot_object_Gamma(2,i,:)),'x--','Color','[0.25, 0.25, 0.25]','linewidth',2,'MarkerSize',10)
plot(1:IP,squeeze(plot_object_Gamma(3,i,:)),'s-','Color','[0.8500    0.3250    0.0980]','linewidth',2,'MarkerSize',10)
plot(1:IP,squeeze(plot_object_Gamma(4,i,:)),'v-','Color','[0.4660    0.6740    0.1880]','linewidth',2,'MarkerSize',10)
plot(0:IP+1,zeros(IP+2,1),'-','Color','[0.25,0.25,0.25]','linewidth',0.5)
xlabel('Deciles of sectors by granular $\Gamma_z^\ast$','interpreter','latex','fontsize',20)
set(gca,'FontSize',16)
set(gca,'xtick',1:10)
set(gca,'ytick',-2:2)
lgd = legend('Home Welfare','Foreign Welfare','Producer Surplus','Consumer Surplus');
set(lgd,'box','off','location','northwest','interpreter','latex','fontsize',20)
xlim([0.5, 10.5])
ylim([-2.0 2.0])
ax = gca;
ax.YAxis.TickLabelFormat = '%g%%';
saveas(gcf,'Results/Graphs/Fig5b','epsc')
