%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: Create_Fig1.m                                                     %
% Date: 03/24/2021                                                        %
% Purpose: Plots Fig4(a), Fig4(b)                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Housekeeping
clear;
close all;
clc

addpath('Results/Data');
set(0,'DefaultLegendAutoUpdate','off')

%% Define variables
IP = 10;           % Number of bins
lambda_length = 3; % Number of different lambdas

%% Load and store data

load('Fig4_Lambda')
pol_sum_reduced_Lambda = zeros(5,lambda_length);
pol_sum_reduced_Lambda(2:end,:) = pol_sum(7:end,:);
pol_sum_reduced_Lambda(1,:) = sum(pol_sum(1:6,:))/6;

load('Fig4_Gamma')
pol_sum_reduced_Gamma = zeros(5,lambda_length);
pol_sum_reduced_Gamma(2:end,:) = pol_sum(7:end,:);
pol_sum_reduced_Gamma(1,:) = sum(pol_sum(1:6,:))/6;

%% Plot graphs

% Figure 4(a)
figure(1)
hb = bar(pol_sum_reduced_Lambda(:,[1,3]));
set(hb(1),'FaceColor',[0 0.4470 0.7410])
set(hb(2),'FaceColor',[0.9290 0.6940 0.1250])
xlabel('Deciles of sectors by $\Lambda_z^*$','interpreter','latex','fontsize',20)
xticklabels({'1-6',7,8,9,10});
set(gca,'fontsize',16)
set(gca,'ytick',0:0.2:1.0)
ylim([0, 1])
lgd = legend('$\lambda=0$','$\lambda=\infty$');
set(lgd,'box','off','location','northeast','interpreter','latex','fontsize',20)
saveas(gcf,'Results/Graphs/Fig4a','epsc')

% Figure 4(b)
figure(2)
hb = bar(pol_sum_reduced_Gamma(:,[1,3]));
set(hb(1),'FaceColor',[0 0.4470 0.7410])
set(hb(2),'FaceColor',[0.9290 0.6940 0.1250])
xlabel('Deciles of sectors by $\Gamma_z^*$','interpreter','latex','fontsize',20)
xticklabels({'1-6',7,8,9,10});
set(gca,'fontsize',16)
set(gca,'ytick',0:0.2:1.0)
ylim([0, 1])
lgd = legend('$\lambda=0$','$\lambda=\infty$');
set(lgd,'box','off','location','northeast','interpreter','latex','fontsize',20)
saveas(gcf,'Results/Graphs/Fig4b','epsc')
