%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: Binning2                                                          %
% Date: 03/28/2021                                                        %
% Purpose: Create bins                                                    %
% Input: SortingVec - vector to be binned                                 %
%        IP         - number of bins                                      %
%        pre_bounds - optional: boundaries of bins                        %
% Output: bounds  - boundaries of bins                                    %                            
%         indices - index which bin an observatin belongs to              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [bounds,indices] = Binning2(SortingVec,IP,pre_bounds)

% Determine upper bounds
if pre_bounds == 0
    bounds = prctile(SortingVec,[1/IP:1/IP:1-1/IP]*100)';
else
    bounds = pre_bounds;
end

% Compute which observation belongs in each index and save indices
indices=zeros(size(SortingVec));
    
indices(SortingVec<bounds(1))=1;

for ip=2:IP-1
    indices(SortingVec<bounds(ip) & SortingVec>=bounds(ip-1))=ip;
end

indices(SortingVec>=bounds(IP-1))=IP;

end
