%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: GE_Tariff.m                                                       %
% Date: 03/28/2021                                                        %
% Purpose: Solves the GE system for Y, YF, wF                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Y,YF,wF,LAMBDA_FH,TOPF1,welfare_moments,cell] = GE_Tariff(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZHL,ZFS,ZFL,tariff,w,wF0,L,LF,Y0,YF0,small,vMU,BER,top)

diff_GE = 1;
iter = 0;
tol = 1e-1;
MAXITER = 51;

while diff_GE>tol && iter<MAXITER
    % Solve Partial Equilibrium Problem
    [K_HH,K_HF,K_FH,K_FF,LAMBDA_FH,LAMBDA_HF,PROF_HH,PROF_HF,SoverMU_FH,SoverMU_FF,TARIFF_FH,TOPF1,welfare_moments,cell] = PE_Tariff(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZHL,ZFS,ZFL,tariff,w,wF0,Y0,YF0,small,vMU,BER,top);
    
    % Set up GE system
    MAT=[sum(ALPHA'.*TARIFF_FH)+sum(ALPHA'.*PROF_HH)-1   sum(ALPHA'.*PROF_HF) -sum(K_HF)*F;...
             sum(ALPHA'.*LAMBDA_FH)-sum(ALPHA'.*TARIFF_FH) -sum(ALPHA'.*LAMBDA_HF) sum(K_HF)*F;...
             sum(ALPHA'.*(SoverMU_FH)) sum(ALPHA'.*SoverMU_FF) (F*sum(K_HF+K_FF)-LF)];
         
    VEC=[-w*L+sum(K_HH)*w*F;sum(K_FH)*w*F;0];
    
    SOL = MAT\VEC;
    
    % Assign values to GE variables
    Y = SOL(1);
    YF = SOL(2);
    wF = SOL(3);
    
    % Shrink step size after 20 iterations
    if iter>20
        step=.15/log(iter-15);
    else
        step=.2;
    end
    
    % Check for convergence and update
    diff_GE = abs(Y-Y0)+abs(YF-YF0)+abs(100*(wF-wF0));
    iter = iter+1;
    Y0 = Y0 + step * (Y-Y0);
    YF0 = YF0 + step * (YF-YF0);
    wF0 = wF0 + step * (wF-wF0);
    
end
    
end