%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: GEreplication_vectorized.m                                        %
% Date: 03/28/2021                                                        %
% Purpose: Solves the GE system for Y, YF, LF                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Y,YF,LF,PHIHVEC,LAMBDAHVEC,TOPF1,welfare_moments,cell] = GEreplication_vectorized(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZFS,ZHL,ZFL,w,wF,L,Y0,YF0,small,vMU,BER,F_adjust)

diff=1;
tol=1e-3;
iter=0;

tic
while diff>tol && iter<51
    % Solve PE
    [K,KF,PHIHVEC,LAMBDA,LAMBDAF,MUHH,MUHF,MUFF,MUFH,LAMBDAHVEC,TOPF1,welfare_moments,cell]=PEreplication_vectorized(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZFS,ZHL,ZFL,w,wF,Y0,YF0,small,vMU,BER,F_adjust);
    
    % Set up linear system composed of (A10) and (A14)
    MAT=[(1-LAMBDA)*(MUHH-1)/MUHH-1 LAMBDAF*(MUHF-1)/MUHF;LAMBDA -LAMBDAF];
    VEC=[-w*L+LAMBDAF*wF*F*KF+(1-LAMBDA)*w*F*K;LAMBDA*w*F*K-LAMBDAF*wF*F*KF];
    SOL=MAT\VEC;

    Y=SOL(1);
    YF=SOL(2);

    diff=abs(Y-Y0)+abs(YF-YF0);
    iter=iter+1;
    if iter<=5
        step=1;
    else
        step=0.5;
    end

    Y0=Y0+step*(Y-Y0);
    YF0=YF0+step*(YF-YF0);
end

% Use (A13) to solve for L* 
LF=1/wF*(wF*F*KF+YF*(1-LAMBDAF)/MUFF+Y*LAMBDA/MUFH);

time=toc;

end