function [KVEC,KFVEC,PHIHVEC,MUHHVEC,MUHFVEC,MUFFVEC,MUFHVEC,LAMBDAHVEC,LAMBDAFVEC,TOPF1,welfare_moments,PHM,SHM] = Inner_Loops(sigma,theta,F,tau,ALPHA,RT,ZH,ZF,w,wF,Y0,YF0,vMU,BER,S,F_adjust)

tol=1e-2;                                                                  % Set tolerance level for A-B loop

%% Set up loops
MH=size(ZH,1);
MF=size(ZF,1);

MCH=w./ZH;
MCF=wF./ZF;

if F_adjust == 1
    F = F*476/S;                                                           % This is required to adjust the fixed costs for the simulation size. This is because we have chosen the normalization sum(alpha)=1.  
end
MCHM=[MCH; tau*MCF];                                                       % This implies that the size of the sector changes as the average alpha decreases as the number of sectors S increases. 
MCFM=[MCF; tau*MCH];                                                       % To keep the model stable, we thus need to adjust the fixed cost F accordingly. Equivalently, we could have had sum(alpha)=S, since this would have implied a constant average alpha of 1.

[MCHM,permH]=sort(MCHM,1);
[MCFM,permF]=sort(MCFM,1);                                                 % Sort marginal costs in home and foreign
IOTAH=(permH>MH);
IOTAF=(permF>MF);                                                          % Find foreign/home entrants in home/foreign markets

MFMH=size(MCHM,1); 


%% Constant Markup
% Set home markups/shares/entry in CMU case
MKP0H=sigma/(sigma-1); 
PHM=(MKP0H*MCHM).^(1-sigma);                                                
SLASTH=PHM./cumsum(PHM); % share of last entrant
checkmatH=(SLASTH>sigma/Y0*w*F./(repmat(ALPHA,MFMH,1)));                   % Checks which firms enter in CMU case 
SHM=(PHM.*checkmatH)./(repmat(sum(PHM.*checkmatH),MFMH,1));                
EPSH=sigma; % used to compute markups at the end of the loop

% Same as above in foreign market
MKP0F=sigma/(sigma-1);
PFM=(MKP0F*MCFM).^(1-sigma);
SLASTF=PFM./cumsum(PFM);     
checkmatF=(SLASTF>sigma/YF0*wF*F./(repmat(ALPHA,MFMH,1)));                 
SFM=(PFM.*checkmatF)./(repmat(sum(PFM.*checkmatF),MFMH,1));                  
EPSF=sigma;

%% Variable Markup 
% Enter loop in VMU case
if vMU==1
    EPSH=vMU_markup(sigma,SHM,BER);
    EPSH(EPSH<=1.25)=1.25;              
    
    EPSF=vMU_markup(sigma,SFM,BER);
    EPSF(EPSF<=1.25)=1.25; 
    
    iter=0;
    diff=1;
    while (diff>tol) && (iter<101)
        iter=iter+1;
        
        % Update shares in home market
        MKPNH=1/2*(MKP0H+EPSH./(EPSH-1));                                  % Set markups for current step
        PHM=(MKPNH.*MCHM).^(1-sigma);                                      % Set prices given markups            
        SHM=(PHM.*checkmatH)./(repmat(sum(PHM.*checkmatH),MFMH,1));        % Salculate shares given prices
        EPSH=vMU_markup(sigma,SHM,BER);
        EPSH(EPSH<=1.25)=1.25; 
        
        % Same in foreign market       
        MKPNF=1/2*(MKP0F+EPSF./(EPSF-1));
        PFM=(MKPNF.*MCFM).^(1-sigma);                                       
        SFM=(PFM.*checkmatF)./(repmat(sum(PFM.*checkmatF),MFMH,1));         
        EPSF=vMU_markup(sigma,SFM,BER);
        EPSF(EPSF<=1.25)=1.25;
        
        % Check for convergence
        diff=sum(sum(abs([MKPNH-MKP0H;MKPNF-MKP0F])));
        
        % Update markups
        MKP0H=MKPNH;
        MKP0F=MKPNF;

    end
    
    % Check entry conditions again with variable markups
    PHM=(MKP0H.*MCHM).^(1-sigma);                                           
    SLASTH=PHM./cumsum(PHM);                                               % Share of last entrant
    checkmatH=(SLASTH>sigma/Y0*w*F./(repmat(ALPHA,MFMH,1)));               % Determine which firms enter with CMU fringe  
    SHM=(PHM.*checkmatH)./(repmat(sum(PHM.*checkmatH),MFMH,1));            % Update shares
    EPSH=vMU_markup(sigma,SHM,BER);
    EPSH(EPSH<=1.25)=1.25; 
    
    % Same in foreign market
    PFM=(MKP0F.*MCFM).^(1-sigma);                                          
    SLASTF=PFM./cumsum(PFM);     
    checkmatF=(SLASTF>sigma/YF0*wF*F./(repmat(ALPHA,MFMH,1)));              
    SFM=(PFM.*checkmatF)./(repmat(sum(PFM.*checkmatF),MFMH,1));          
    EPSF=vMU_markup(sigma,SFM,BER);
    EPSF(EPSF<=1.25)=1.25;
    
    % Same loop as before, but with new entrants
    iter=0;
    diff=1;
    while (diff>tol) && (iter<101)
        iter=iter+1;

        MKPNH=1/2*(MKP0H+EPSH./(EPSH-1));
        PHM=(MKPNH.*MCHM).^(1-sigma);                                     
        SHM=(PHM.*checkmatH)./(repmat(sum(PHM.*checkmatH),MFMH,1));         
        
        MKPNF=1/2*(MKP0F+EPSF./(EPSF-1));
        PFM=(MKPNF.*MCFM).^(1-sigma);                                           
        SFM=(PFM.*checkmatF)./(repmat(sum(PFM.*checkmatF),MFMH,1));         
        
        EPSH=vMU_markup(sigma,SHM,BER);
        EPSH(EPSH<=1.25)=1.25;
        
        EPSF=vMU_markup(sigma,SFM,BER);
        EPSF(EPSF<=1.25)=1.25;

        diff=sum(sum(abs([MKPNH-MKP0H;MKPNF-MKP0F])));

        MKP0H=MKPNH;
        MKP0F=MKPNF;

    end
end

checkmatH=(SHM>0);                                                         % Matrix of firms that enter in home in equilibrium above
checkmatF=(SFM>0); 
MUHM=EPSH./(EPSH-1);                                                       % Markups of firms in home
MUFM=EPSF./(EPSF-1);

%% Compute Summary Statistics 
KVEC=sum(checkmatH);                                                       % Vector of number of firms that enter in home
KFVEC=sum(checkmatF);
PHIHVEC=1./(1+(tau*wF/w)^theta.*RT);                                       % Expected import share vector in home
MUHHVEC=sum((1-IOTAH).*SHM./MUHM);                                         
MUHFVEC=sum(IOTAF.*SFM./MUFM);
MUFFVEC=sum((1-IOTAF).*SFM./MUFM);
MUFHVEC=sum(IOTAH.*SHM./MUHM);                                      
LAMBDAHVEC=sum(IOTAH.*SHM);                                                % Realized import share vector in home
LAMBDAFVEC=sum(IOTAF.*SFM);

% Auxiliary variables for moments
KHH = sum(checkmatH.*(1-IOTAH));                                           
KHF = sum(checkmatF.*IOTAF); 
TOPF1 = max(SHM.*IOTAH);

% Welfare moments
P_index = sum(PHM.*checkmatH).^(1/(1-sigma));                              % Home price index
PF_index = sum(PFM.*checkmatF).^(1/(1-sigma));                             % Foreign price index
profits = sum(SHM.*(1-IOTAH)./EPSH).*ALPHA*Y0 + ...                        % Total profits of home firms (in both home and foreign markets) 
          sum(SFM.*IOTAF./EPSF).*ALPHA*YF0 - ...
          KHH*w*F-KHF*wF*F;    

welfare_moments = zeros(3,length(profits));
welfare_moments(1,:) = P_index;
welfare_moments(2,:) = profits;
welfare_moments(3,:) = PF_index;

end