%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: PE_Tariff.m                                                       %
% Date: 03/28/2021                                                        %
% Purpose: Solves the partial equilibrium problem.              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [K_HH,K_HF,K_FH,K_FF,LAMBDA_FH,LAMBDA_HF,PROF_HH,PROF_HF,SoverMU_FH,SoverMU_FF,TARIFF_FH,TOPF1,welfare_moments,cell] = PE_Tariff(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZHL,ZFS,ZFL,tariff,w,wF,Y0,YF0,small,vMU,BER,top)

    S=size(ZHL,2)+size(ZHS,2);                                             % Fix number of sectors
    
    ALPHAS=ALPHA(small);
    ALPHAL=ALPHA(~small);
    
    tariffS=tariff(small);
    tariffL=tariff(~small);
    
    % Initialize vectors that contain PE data
    K_HH = zeros(1,S);
    K_HF = zeros(1,S);
    K_FH = zeros(1,S);
    K_FF = zeros(1,S);
    LAMBDA_FH = zeros(1,S);
    LAMBDA_HF = zeros(1,S);
    PROF_HH = zeros(1,S);
    PROF_HF = zeros(1,S);
    SoverMU_FH = zeros(1,S);
    SoverMU_FF = zeros(1,S);
    TARIFF_FH = zeros(1,S);
    TOPF1 = zeros(1,S);
    welfare_moments = zeros(3,S);
    
    [K_HH(small),K_HF(small),K_FH(small),K_FF(small),LAMBDA_FH(small),...
        LAMBDA_HF(small),PROF_HH(small),PROF_HF(small),SoverMU_FH(small),...
        SoverMU_FF(small),TARIFF_FH(small),TOPF1(small),welfare_moments(:,small),IOTAHS,PHMS,SHMS,checkmatHS] = ...
        Inner_Loops_Tariff(sigma,theta,F,tau,ALPHAS',RTS,ZHS,ZFS,tariffS,w,wF,Y0,YF0,vMU,BER,S,top);
    [K_HH(~small),K_HF(~small),K_FH(~small),K_FF(~small),LAMBDA_FH(~small),...
        LAMBDA_HF(~small),PROF_HH(~small),PROF_HF(~small),SoverMU_FH(~small),...
        SoverMU_FF(~small),TARIFF_FH(~small),TOPF1(~small),welfare_moments(:,~small),IOTAHL,PHML,SHML,checkmatHL] = ...
        Inner_Loops_Tariff(sigma,theta,F,tau,ALPHAL',RTL,ZHL,ZFL,tariffL,w,wF,Y0,YF0,vMU,BER,S,top); 
    
    cell = {IOTAHS,IOTAHL;PHMS.^(1/(1-sigma)),PHML.^(1/(1-sigma));SHMS,SHML;checkmatHS,checkmatHL};
end