%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: Main_Tariff.m                                                     %
% Date: 03/28/2021                                                        %
% Purpose: Solves the partial equilibrium problem                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [K,KF,PHIHVEC,LAMBDA,LAMBDAF,MUHH,MUHF,MUFF,MUFH,LAMBDAHVEC,TOPF1,welfare_moments,cell] = PEreplication_vectorized(sigma,theta,F,tau,ALPHA,RTS,RTL,ZHS,ZFS,ZHL,ZFL,w,wF,Y0,YF0,small,vMU,BER,F_adjust)

S=size(ZHL,2)+size(ZHS,2); % fix number of sectors

ALPHAS=ALPHA(small);
ALPHAL=ALPHA(~small);

% Initialize vectors that contain PE data
PHIHVEC=zeros(1,S);
MUHHVEC=zeros(1,S);
MUHFVEC=zeros(1,S);
MUFFVEC=zeros(1,S);
MUFHVEC=zeros(1,S);
KVEC=zeros(1,S);
KFVEC=zeros(1,S);
LAMBDAHVEC=zeros(1,S);
LAMBDAFVEC=zeros(1,S); 
TOPF1 = zeros(1,S);
welfare_moments=zeros(3,S);

% Solve inner loops separately for small and large sectors (for speed)
[KVEC(small),KFVEC(small),PHIHVEC(small),MUHHVEC(small),MUHFVEC(small),MUFFVEC(small),MUFHVEC(small),LAMBDAHVEC(small),LAMBDAFVEC(small),TOPF1(small),welfare_moments(:,small),PHMS,SHMS]=...
    Inner_Loops(sigma,theta,F,tau,ALPHAS',RTS,ZHS,ZFS,w,wF,Y0,YF0,vMU,BER,S,F_adjust);
[KVEC(~small),KFVEC(~small),PHIHVEC(~small),MUHHVEC(~small),MUHFVEC(~small),MUFFVEC(~small),MUFHVEC(~small),LAMBDAHVEC(~small),LAMBDAFVEC(~small),TOPF1(~small),welfare_moments(:,~small),PHML,SHML]=...
    Inner_Loops(sigma,theta,F,tau,ALPHAL',RTL,ZHL,ZFL,w,wF,Y0,YF0,vMU,BER,S,F_adjust);

cell = {PHMS.^(1/(1-sigma)),PHML.^(1/(1-sigma));SHMS,SHML};

% Take averages of vectors to obtain aggregates
K=sum(KVEC);           
KF=sum(KFVEC);
LAMBDA=sum(ALPHA'.*LAMBDAHVEC);
LAMBDAF=sum(ALPHA'.*LAMBDAFVEC);
MUHH=(1-LAMBDA)/sum(ALPHA'.*MUHHVEC);
MUHF=LAMBDAF/sum(ALPHA'.*MUHFVEC);
MUFF=(1-LAMBDAF)/sum(ALPHA'.*MUFFVEC);
MUFH=LAMBDA/sum(ALPHA'.*MUFHVEC);

end

