%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Maximilian Vogler                                               %
% Name: Create_Figs6_7.m                                                  %
% Date: 03/28/2021                                                        %
% Purpose: Plots Fig6(a), Fig6(b), Fig7(a) and Fig7(b)                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Housekeeping
clear;
close all;
clc

addpath('Results/Data');
set(0,'DefaultLegendAutoUpdate','off')
set(groot,'defaultLegendAutoUpdate','off')

%% Load and store data

load('Data_CM')

CM_indices_granular = mean(plot_indices_granular);
CM_indices_uniform = mean(plot_indices_uniform);
CM_profits_granular = mean(plot_profits_granular);
CM_profits_uniform = mean(plot_profits_uniform);
CM_revenue_granular = mean(plot_revenue_granular);
CM_revenue_uniform = mean(plot_revenue_uniform);
CM_welfare_granular = mean(plot_welfare_granular);
CM_welfare_uniform = mean(plot_welfare_uniform);
CM_welfarF_granular = mean(plot_welfarF_granular);
CM_welfarF_uniform = mean(plot_welfarF_uniform);

load('Data_VM')

VM_indices_granular = mean(plot_indices_granular);
VM_indices_uniform = mean(plot_indices_uniform);
VM_profits_granular = mean(plot_profits_granular);
VM_profits_uniform = mean(plot_profits_uniform);
VM_revenue_granular = mean(plot_revenue_granular);
VM_revenue_uniform = mean(plot_revenue_uniform);
VM_welfare_granular = mean(plot_welfare_granular);
VM_welfare_uniform = mean(plot_welfare_uniform);
VM_welfarF_granular = mean(plot_welfarF_granular);
VM_welfarF_uniform = mean(plot_welfarF_uniform);

%% Set plotting parameters

IP = 10;                                                                   % Number of bins

%% Prepare plotting data

CM_welfar2_uniform = CM_revenue_uniform + CM_profits_uniform - CM_indices_uniform;
CM_welfar2_granular = CM_revenue_granular + CM_profits_granular - CM_indices_granular;

VM_welfar2_uniform = VM_revenue_uniform + VM_profits_uniform - VM_indices_uniform;
VM_welfar2_granular = VM_revenue_granular + VM_profits_granular - VM_indices_granular;

Fig5a_data = [(CM_welfare_uniform*IP)' ((VM_welfare_uniform-CM_welfare_uniform)*IP)' ((VM_welfare_granular-VM_welfare_uniform)*IP)'];
Fig5b_data = [((VM_welfare_granular-VM_welfare_uniform).*sign(VM_welfare_granular)*IP)' ((VM_welfare_uniform-CM_welfare_uniform).*sign(VM_welfar2_uniform)*IP)'];

%% Plot

% Figure 6(a)
figure(1)
bar1 = bar(Fig5a_data,'stacked');
set(bar1(1), 'FaceColor','[0.6350, 0.0780, 0.1840]','FaceAlpha',0.5)
set(bar1(2), 'FaceColor','[0.900, 0.20, 0.05]','FaceAlpha',0.5)
set(bar1(3), 'FaceColor','[0, 0.4470, 0.7410]','FaceAlpha',0.33)
xlabel('Deciles of sectors by foreign share $\Lambda_z$','interpreter','latex','fontsize',20)
set(gca,'FontSize',16)
set(gca,'xtick',1:10)
lgd = legend('Uniform CM','Uniform VM','Granular VM');
set(lgd,'box','off','location','northwest','interpreter','latex','fontsize',20)
xlim([0.5, 10.5])
ylim([0, 1.0]);
ax = gca;
ax.YAxis.TickLabelFormat = '%g%%';
saveas(gcf,'Results/Graphs/Fig6a','epsc')

% Figure 6(b)
figure(2)
hb = bar(Fig5b_data);
set(hb(1), 'FaceColor','[0, 0.4470, 0.7410]','FaceAlpha',0.33)
set(hb(2), 'FaceColor','[0.900, 0.20, 0.05]','FaceAlpha',0.5)
xlabel('Deciles of sectors by foreign share $\Lambda_z$','interpreter','latex','fontsize',20)
set(gca,'FontSize',16)
set(gca,'xtick',1:10)
lgd = legend('Granular $-$ Uniform','VM $-$ CM','interpreter','latex');
set(lgd,'box','off','location','northwest','interpreter','latex','fontsize',20)
xlim([0.5, 10.5])
ylim([-0.05, 0.2]);
ax = gca;
ax.YAxis.TickLabelFormat = '%g%%';
saveas(gcf,'Results/Graphs/Fig6b','epsc')

% Figure 7(a)
figure(3)
plot(1:IP,IP*VM_welfar2_uniform,'o-','Color','[0, 0.4470, 0.7410]','linewidth',2,'MarkerSize',10);
hold on
plot(1:IP,IP*VM_welfarF_uniform,'x--','Color','[0.25, 0.25, 0.25]','linewidth',2,'MarkerSize',10);
plot(1:IP,IP*VM_revenue_uniform,'^-','Color','[0.9290    0.6940    0.1250]','linewidth',2,'MarkerSize',10);
plot(1:IP,IP*VM_profits_uniform,'s-','Color','[0.8500    0.3250    0.0980]','linewidth',2,'MarkerSize',10);
plot(1:IP,-IP*VM_indices_uniform,'v-','Color','[0.4660    0.6740    0.1880]','linewidth',2,'MarkerSize',10);
plot(0:IP+1,zeros(IP+2,1),'-','Color','[0.25,0.25,0.25]','linewidth',0.5)
xlabel('Deciles of sectors by foreign share $\Lambda_z$','interpreter','latex','fontsize',20)
set(gca,'FontSize',16)
set(gca,'xtick',1:10)
set(gca,'ytick',-1:.5:1)
lgd = legend('Home welfare','Foreign welfare','Tariff revenue','Producer surplus','Consumer surplus');
set(lgd,'box','off','location','northwest','interpreter','latex','fontsize',20)
xlim([0.5, 10.5])
ylim([-0.85, 1])
ax = gca;
ax.YAxis.TickLabelFormat = '%g%%';
saveas(gcf,'Results/Graphs/Fig7a','epsc')

% Figure 7(b)
figure(4)
plot(1:IP,IP*VM_welfar2_granular,'o-','Color','[0, 0.4470, 0.7410]','linewidth',2,'MarkerSize',10);
hold on
plot(1:IP,IP*VM_welfarF_granular,'x--','Color','[0.25, 0.25, 0.25]','linewidth',2,'MarkerSize',10);
plot(1:IP,IP*VM_revenue_granular,'^-','Color','[0.9290    0.6940    0.1250]','linewidth',2,'MarkerSize',10);
plot(1:IP,IP*VM_profits_granular,'s-','Color','[0.8500    0.3250    0.0980]','linewidth',2,'MarkerSize',10);
plot(1:IP,-IP*VM_indices_granular,'v-','Color','[0.4660    0.6740    0.1880]','linewidth',2,'MarkerSize',10);
plot(0:IP+1,zeros(IP+2,1),'-','Color','[0.25,0.25,0.25]','linewidth',0.5)
xlabel('Deciles of sectors by foreign share $\Lambda_z$','interpreter','latex','fontsize',20)
set(gca,'FontSize',16)
set(gca,'xtick',1:10)
set(gca,'ytick',-1:.5:1)
lgd = legend('Home welfare','Foreign welfare','Tariff revenue','Producer surplus','Consumer surplus');
set(lgd,'box','off','location','northwest','interpreter','latex','fontsize',20)
xlim([0.5, 10.5])
ylim([-0.85, 1])
ax = gca;
ax.YAxis.TickLabelFormat = '%g%%';
saveas(gcf,'Results/Graphs/Fig7b','epsc')
